@@ -17,11 +17,16 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.HostDevice;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.or;
+
 /**
  * A service to manage host devices attached to a virtual machine.
  *
@@ -65,6 +70,10 @@ public interface VmHostDevicesService {
      * @status added
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            or(mandatory(device().id()), mandatory(device().name()));
+        }
         /**
          * The host device to be attached to given virtual machine.
          *
@@ -84,7 +93,7 @@ public interface VmHostDevicesService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         /**
          * Retrieved list of host devices attached to given virtual machine.
          *
