@@ -62,6 +62,10 @@ public class Builders {
         return new AuthorizedKeyBuilder();
     }
     
+    public static BackupBuilder backup() {
+        return new BackupBuilder();
+    }
+    
     public static BalanceBuilder balance() {
         return new BalanceBuilder();
     }
