@@ -17,6 +17,7 @@ package org.ovirt.engine.sdk4.builders;
 
 import java.lang.Boolean;
 import java.lang.String;
+import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -29,10 +30,13 @@ import org.ovirt.engine.sdk4.types.CpuProfile;
 import org.ovirt.engine.sdk4.types.DataCenter;
 import org.ovirt.engine.sdk4.types.Display;
 import org.ovirt.engine.sdk4.types.ErrorHandling;
+import org.ovirt.engine.sdk4.types.ExternalProvider;
 import org.ovirt.engine.sdk4.types.FencingPolicy;
+import org.ovirt.engine.sdk4.types.FirewallType;
 import org.ovirt.engine.sdk4.types.GlusterHook;
 import org.ovirt.engine.sdk4.types.GlusterVolume;
 import org.ovirt.engine.sdk4.types.Ksm;
+import org.ovirt.engine.sdk4.types.LogMaxMemoryUsedThresholdType;
 import org.ovirt.engine.sdk4.types.MacPool;
 import org.ovirt.engine.sdk4.types.MemoryPolicy;
 import org.ovirt.engine.sdk4.types.MigrationOptions;
@@ -58,7 +62,9 @@ public class ClusterBuilder {
     private Display display;
     private List<ClusterFeature> enabledFeatures;
     private ErrorHandling errorHandling;
+    private List<ExternalProvider> externalNetworkProviders;
     private FencingPolicy fencingPolicy;
+    private FirewallType firewallType;
     private List<GlusterHook> glusterHooks;
     private Boolean glusterService;
     private String glusterTunedProfile;
@@ -67,6 +73,8 @@ public class ClusterBuilder {
     private String href;
     private String id;
     private Ksm ksm;
+    private BigInteger logMaxMemoryUsedThreshold;
+    private LogMaxMemoryUsedThresholdType logMaxMemoryUsedThresholdType;
     private MacPool macPool;
     private Boolean maintenanceReasonRequired;
     private Network managementNetwork;
@@ -315,6 +323,41 @@ public class ClusterBuilder {
     }
     
     
+    public ClusterBuilder externalNetworkProviders(List<ExternalProvider> newExternalNetworkProviders) {
+        if (newExternalNetworkProviders != null) {
+            if (externalNetworkProviders == null) {
+                externalNetworkProviders = new ArrayList<>(newExternalNetworkProviders);
+            }
+            else {
+                externalNetworkProviders.addAll(newExternalNetworkProviders);
+            }
+        }
+        return this;
+    }
+    
+    public ClusterBuilder externalNetworkProviders(ExternalProvider... newExternalNetworkProviders) {
+        if (newExternalNetworkProviders != null) {
+            if (externalNetworkProviders == null) {
+                externalNetworkProviders = new ArrayList<>(newExternalNetworkProviders.length);
+            }
+            Collections.addAll(externalNetworkProviders, newExternalNetworkProviders);
+        }
+        return this;
+    }
+    
+    public ClusterBuilder externalNetworkProviders(ExternalProviderBuilder... newExternalNetworkProviders) {
+        if (newExternalNetworkProviders != null) {
+            if (externalNetworkProviders == null) {
+                externalNetworkProviders = new ArrayList<>(newExternalNetworkProviders.length);
+            }
+            for (ExternalProviderBuilder builder : newExternalNetworkProviders) {
+                externalNetworkProviders.add(builder.build());
+            }
+        }
+        return this;
+    }
+    
+    
     public ClusterBuilder fencingPolicy(FencingPolicy newFencingPolicy) {
         fencingPolicy = newFencingPolicy;
         return this;
@@ -331,6 +374,12 @@ public class ClusterBuilder {
     }
     
     
+    public ClusterBuilder firewallType(FirewallType newFirewallType) {
+        firewallType = newFirewallType;
+        return this;
+    }
+    
+    
     public ClusterBuilder glusterHooks(List<GlusterHook> newGlusterHooks) {
         if (newGlusterHooks != null) {
             if (glusterHooks == null) {
@@ -457,6 +506,48 @@ public class ClusterBuilder {
     }
     
     
+    public ClusterBuilder logMaxMemoryUsedThreshold(int newLogMaxMemoryUsedThreshold) {
+        logMaxMemoryUsedThreshold = BigInteger.valueOf((long) newLogMaxMemoryUsedThreshold);
+        return this;
+    }
+    
+    public ClusterBuilder logMaxMemoryUsedThreshold(Integer newLogMaxMemoryUsedThreshold) {
+        if (newLogMaxMemoryUsedThreshold == null) {
+            logMaxMemoryUsedThreshold = null;
+        }
+        else {
+            logMaxMemoryUsedThreshold = BigInteger.valueOf(newLogMaxMemoryUsedThreshold.longValue());
+        }
+        return this;
+    }
+    
+    public ClusterBuilder logMaxMemoryUsedThreshold(long newLogMaxMemoryUsedThreshold) {
+        logMaxMemoryUsedThreshold = BigInteger.valueOf(newLogMaxMemoryUsedThreshold);
+        return this;
+    }
+    
+    public ClusterBuilder logMaxMemoryUsedThreshold(Long newLogMaxMemoryUsedThreshold) {
+        if (newLogMaxMemoryUsedThreshold == null) {
+            logMaxMemoryUsedThreshold = null;
+        }
+        else {
+            logMaxMemoryUsedThreshold = BigInteger.valueOf(newLogMaxMemoryUsedThreshold.longValue());
+        }
+        return this;
+    }
+    
+    public ClusterBuilder logMaxMemoryUsedThreshold(BigInteger newLogMaxMemoryUsedThreshold) {
+        logMaxMemoryUsedThreshold = newLogMaxMemoryUsedThreshold;
+        return this;
+    }
+    
+    
+    public ClusterBuilder logMaxMemoryUsedThresholdType(LogMaxMemoryUsedThresholdType newLogMaxMemoryUsedThresholdType) {
+        logMaxMemoryUsedThresholdType = newLogMaxMemoryUsedThresholdType;
+        return this;
+    }
+    
+    
     public ClusterBuilder macPool(MacPool newMacPool) {
         macPool = newMacPool;
         return this;
@@ -823,7 +914,9 @@ public class ClusterBuilder {
         container.display(display);
         container.enabledFeatures(enabledFeatures);
         container.errorHandling(errorHandling);
+        container.externalNetworkProviders(externalNetworkProviders);
         container.fencingPolicy(fencingPolicy);
+        container.firewallType(firewallType);
         container.glusterHooks(glusterHooks);
         container.glusterService(glusterService);
         container.glusterTunedProfile(glusterTunedProfile);
@@ -832,6 +925,8 @@ public class ClusterBuilder {
         container.href(href);
         container.id(id);
         container.ksm(ksm);
+        container.logMaxMemoryUsedThreshold(logMaxMemoryUsedThreshold);
+        container.logMaxMemoryUsedThresholdType(logMaxMemoryUsedThresholdType);
         container.macPool(macPool);
         container.maintenanceReasonRequired(maintenanceReasonRequired);
         container.managementNetwork(managementNetwork);
