@@ -67,6 +67,9 @@ public class XmlHostDeviceReader {
                 case "description":
                 object.description(reader.readString());
                 break;
+                case "driver":
+                object.driver(reader.readString());
+                break;
                 case "host":
                 object.host(XmlHostReader.readOne(reader));
                 break;
@@ -104,7 +107,7 @@ public class XmlHostDeviceReader {
                 if (rel != null && href != null) {
                     links.add(new String[]{rel, href});
                 }
-                reader.next();
+                reader.skip();
                 break;
                 default:
                 reader.skip();
