@@ -30,6 +30,11 @@ public interface TemplateDisksService extends Service {
      * The order of the returned list of disks isn't guaranteed.
      */
     public interface ListRequest extends Request<ListRequest, ListResponse> {
+        /**
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        ListRequest follow(String follow);
         /**
          * Sets the maximum number of disks to return. If not specified all the disks are returned.
          */
