@@ -1674,6 +1674,10 @@ public interface VmService extends MeasurableService {
      */
     AssignedAffinityLabelsService affinityLabelsService();
     VmApplicationsService applicationsService();
+    /**
+     * List of backups of this virtual machine.
+     */
+    VmBackupsService backupsService();
     VmCdromsService cdromsService();
     /**
      * List of disks attached to this virtual machine.
