@@ -19,6 +19,10 @@ import java.math.BigInteger;
 
 public interface GracePeriod {
     BigInteger expiry();
+    Byte expiryAsByte();
+    Short expiryAsShort();
+    Integer expiryAsInteger();
+    Long expiryAsLong();
     
     boolean expiryPresent();
     
