@@ -42,10 +42,18 @@ public interface StorageConnection extends Identified {
     boolean mountOptionsPresent();
     
     BigInteger nfsRetrans();
+    Byte nfsRetransAsByte();
+    Short nfsRetransAsShort();
+    Integer nfsRetransAsInteger();
+    Long nfsRetransAsLong();
     
     boolean nfsRetransPresent();
     
     BigInteger nfsTimeo();
+    Byte nfsTimeoAsByte();
+    Short nfsTimeoAsShort();
+    Integer nfsTimeoAsInteger();
+    Long nfsTimeoAsLong();
     
     boolean nfsTimeoPresent();
     
@@ -62,6 +70,10 @@ public interface StorageConnection extends Identified {
     boolean pathPresent();
     
     BigInteger port();
+    Byte portAsByte();
+    Short portAsShort();
+    Integer portAsInteger();
+    Long portAsLong();
     
     boolean portPresent();
     
@@ -85,6 +97,10 @@ public interface StorageConnection extends Identified {
     
     boolean vfsTypePresent();
     
+    GlusterVolume glusterVolume();
+    
+    boolean glusterVolumePresent();
+    
     Host host();
     
     boolean hostPresent();
